@@ -1,5 +1,5 @@
 /*
- * $Id: Server.cc,v 1.26 2008/02/18 22:51:21 rousskov Exp $
+ * $Id$
  *
  * DEBUG:
  * AUTHOR: Duane Wessels
@@ -39,10 +39,11 @@
 #include "HttpReply.h"
 #include "TextException.h"
 #include "errorpage.h"
+#include "SquidTime.h"
 
 #if USE_ADAPTATION
 #include "adaptation/AccessCheck.h"
-#include "adaptation/Service.h"
+#include "adaptation/Iterator.h"
 #endif
 
 // implemented in client_side_reply.cc until sides have a common parent
@@ -173,6 +174,10 @@ ServerStateData::serverComplete()
 
     completed = true;
 
+    HttpRequest *r = originalRequest();
+    r->hier.total_response_time = r->hier.first_conn_start.tv_sec ?
+        tvSubMsec(r->hier.first_conn_start, current_time) : -1;
+    
     if (requestBodySource != NULL)
         stopConsumingFrom(requestBodySource);
 
@@ -503,24 +508,11 @@ ServerStateData::originalRequest()
 }
 
 #if USE_ADAPTATION
-/*
- * Initiate an ICAP transaction.  Return true on success.
- * Caller will handle error condition by generating a Squid error message
- * or take other action.
- */
-bool
-ServerStateData::startAdaptation(Adaptation::ServicePointer service, HttpRequest *cause)
+/// Initiate an asynchronous adaptation transaction which will call us back.
+void
+ServerStateData::startAdaptation(const Adaptation::ServiceGroupPointer &group, HttpRequest *cause)
 {
     debugs(11, 5, "ServerStateData::startAdaptation() called");
-    if (!service) {
-        debugs(11, 3, "ServerStateData::startAdaptation fails: lack of service");
-        return false;
-    }
-    if (service->broken()) {
-        debugs(11, 3, "ServerStateData::startAdaptation fails: broken service");
-        return false;
-    }
-
     // check whether we should be sending a body as well
     // start body pipe to feed ICAP transaction if needed
     assert(!virginBodyDestination);
@@ -536,9 +528,10 @@ ServerStateData::startAdaptation(Adaptation::ServicePointer service, HttpRequest
             virginBodyDestination->setBodySize(size);
     }
 
-    adaptedHeadSource = initiateAdaptation(service->makeXactLauncher(
-                                               this, vrep, cause));
-    return adaptedHeadSource != NULL;
+    adaptedHeadSource = initiateAdaptation(
+        new Adaptation::Iterator(this, vrep, cause, group));
+    startedAdaptation = adaptedHeadSource != NULL;
+    Must(startedAdaptation);
 }
 
 // properly cleans up ICAP-related state
@@ -753,7 +746,7 @@ ServerStateData::handleAdaptationAborted(bool bypassable)
 }
 
 void
-ServerStateData::adaptationAclCheckDone(Adaptation::ServicePointer service)
+ServerStateData::adaptationAclCheckDone(Adaptation::ServiceGroupPointer group)
 {
     adaptationAccessCheckPending = false;
 
@@ -768,34 +761,22 @@ ServerStateData::adaptationAclCheckDone(Adaptation::ServicePointer service)
     }
     // TODO: Should we check receivedBodyTooLarge on the server-side as well?
 
-    startedAdaptation = startAdaptation(service, originalRequest());
-
-    if (!startedAdaptation && (!service || service->cfg().bypass)) {
-        // handle ICAP start failure when no service was selected
-        // or where the selected service was optional
+    if (!group) {
+        debugs(11,3, HERE << "no adapation needed");
         setFinalReply(virginReply());
         processReplyBody();
         return;
     }
 
-    if (!startedAdaptation) {
-        // handle start failure for an essential ICAP service
-        ErrorState *err = errorCon(ERR_ICAP_FAILURE,
-                                   HTTP_INTERNAL_SERVER_ERROR, originalRequest());
-        err->xerrno = errno;
-        errorAppendEntry(entry, err);
-        abortTransaction("ICAP start failure");
-        return;
-    }
-
+    startAdaptation(group, originalRequest());
     processReplyBody();
 }
 
 void
-ServerStateData::adaptationAclCheckDoneWrapper(Adaptation::ServicePointer service, void *data)
+ServerStateData::adaptationAclCheckDoneWrapper(Adaptation::ServiceGroupPointer group, void *data)
 {
     ServerStateData *state = (ServerStateData *)data;
-    state->adaptationAclCheckDone(service);
+    state->adaptationAclCheckDone(group);
 }
 #endif
 
@@ -820,6 +801,7 @@ ServerStateData::adaptOrFinalizeReply()
     adaptationAccessCheckPending = Adaptation::AccessCheck::Start(
                                        Adaptation::methodRespmod, Adaptation::pointPreCache,
                                        request, virginReply(), adaptationAclCheckDoneWrapper, this);
+    debugs(11,5, HERE << "adaptationAccessCheckPending=" << adaptationAccessCheckPending);
     if (adaptationAccessCheckPending)
         return;
 #endif
