@@ -37,7 +37,7 @@
 #include "StoreIOBuffer.h"
 #include "forward.h"
 #include "BodyPipe.h"
-#include "ICAP/AsyncJob.h"
+#include "base/AsyncJob.h"
 #include "CommCalls.h"
 
 #if USE_ADAPTATION
@@ -86,8 +86,8 @@ public:
     virtual  HttpRequest *originalRequest();
 
 #if USE_ADAPTATION
-    void adaptationAclCheckDone(Adaptation::ServicePointer service);
-    static void adaptationAclCheckDoneWrapper(Adaptation::ServicePointer service, void *data);
+    void adaptationAclCheckDone(Adaptation::ServiceGroupPointer group);
+    static void adaptationAclCheckDoneWrapper(Adaptation::ServiceGroupPointer group, void *data);
 
     // ICAPInitiator: start an ICAP transaction and receive adapted headers.
     virtual void noteAdaptationAnswer(HttpMsg *message);
@@ -141,7 +141,7 @@ protected:
     bool abortOnBadEntry(const char *abortReason);
 
 #if USE_ADAPTATION
-    bool startAdaptation(Adaptation::ServicePointer service, HttpRequest *cause);
+    void startAdaptation(const Adaptation::ServiceGroupPointer &group, HttpRequest *cause);
     void adaptVirginReplyBody(const char *buf, ssize_t len);
     void cleanAdaptation();
     virtual bool doneWithAdaptation() const;   /**< did we end ICAP communication? */
