@@ -1,6 +1,6 @@
 
 /*
- * $Id: typedefs.h,v 1.194 2008/02/26 21:49:35 amosjeffries Exp $
+ * $Id$
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -165,8 +165,6 @@ typedef struct _storeSwapLogData storeSwapLogData;
 
 typedef struct _StatHist StatHist;
 
-typedef struct _ClientInfo ClientInfo;
-
 typedef struct _cd_guess_stats cd_guess_stats;
 
 typedef struct _CacheDigest CacheDigest;
@@ -201,9 +199,10 @@ typedef void DCCB(int, int errflag, void *data);	/* disk close CB */
 typedef void DUCB(int errflag, void *data);	/* disk unlink CB */
 typedef void DTCB(int errflag, void *data);	/* disk trunc CB */
 
-typedef void FQDNH(const char *, void *);
+class DnsLookupDetails;
+typedef void FQDNH(const char *, const DnsLookupDetails &details, void *);
 typedef void IDCB(const char *ident, void *data);
-typedef void IPH(const ipcache_addrs *, void *);
+typedef void IPH(const ipcache_addrs *, const DnsLookupDetails &details, void *);
 typedef void IRCB(struct peer *, peer_t, protocol_t, void *, void *data);
 
 class FwdServer;
@@ -235,9 +234,6 @@ typedef void StatHistBinDumper(StoreEntry *, int idx, double val, double size, i
 /* MD5 cache keys */
 typedef unsigned char cache_key;
 
-/* context-based debugging, the actual type is subject to change */
-typedef int Ctx;
-
 /* in case we want to change it later */
 typedef ssize_t mb_size_t;
 
